<?php
defined('BASEPATH') OR exit('No direct script access allowed');

class Blog extends CI_Controller{
  public function index()
  {
    // Load pagination library
    $this->load->library('pagination');
    // Fetch page details from the database
    $page = $this->crud->getDataSingle('pages', 'blog', 'pid', null);
    $config['page'] = $page;
    $config['pageType'] = 'static';
    $config['seoTitle'] = $page->seo_title;
    $config['seoDesc'] = $page->seo_description;
    $config['seoKey'] = $page->seo_keywords;
    // Pagination settings
    $paginationConfig = [
      'base_url' => base_url('blog'), // URL for the pagination links
      'total_rows' => $this->crud->getCountAll('blog_post'), // Total number of entries in the 'work' table
      'per_page' => 9, // Number of entries per page
      'uri_segment' => 2, // URL segment where the page number appears
      'full_tag_open' => '<ul class="styled-pagination mt-4 text-center">', // Opening tag for pagination container
      'full_tag_close' => '</ul>', // Closing tag for pagination container
      'num_tag_open' => '<li>', // Opening tag for individual page link
      'num_tag_close' => '</li>', // Closing tag for individual page link
      'cur_tag_open' => '<li><a href="#" class="active">', // Opening tag for active page link
      'cur_tag_close' => '</a></li>', // Closing tag for active page link
      'prev_link' => '<span class="icon fa fa-angle-left"></span>', // Previous page link text
      'prev_tag_open' => '<li>', // Opening tag for previous page link
      'prev_tag_close' => '</li>', // Closing tag for previous page link
      'next_link' => '<span class="icon fa fa-angle-right"></span>', // Next page link text
      'next_tag_open' => '<li>', // Opening tag for next page link
      'next_tag_close' => '</li>', // Closing tag for next page link
      'first_tag_open' => '<li>', // Opening tag for first page link
      'first_tag_close' => '</li>', // Closing tag for first page link
      'last_tag_open' => '<li>', // Opening tag for last page link
      'last_tag_close' => '</li>', // Closing tag for last page link
    ];
    // Initialize pagination with the config
    $this->pagination->initialize($paginationConfig);
    // Get the current page number from the URL segment
    $pageNumber = ($this->uri->segment(2)) ? $this->uri->segment(2) : 0;
    // Fetch data from the 'work' table for the current page
    $data['blog_posts'] = $this->crud->get_paginated_data('blog_post', $paginationConfig['per_page'], $pageNumber, 'id', 'desc');
    $data['pagination_links'] = $this->pagination->create_links();
    // Load the views with the page data and pagination links
    $this->load->view('public/common/public-header', $config);
    $this->load->view('public/blog', $data);
    $this->load->view('public/common/public-footer');
  }
  public function details($uri=null)
  {
    if ($this->crud->getCount('blog_post', 'uri', cleanVal($uri)) > 0) {
      // $this->output->enable_profiler(TRUE);

      $config['page'] = $this->crud->getDataSingle('blog_post', cleanVal($uri), 'uri', null);
      $config['pageType'] = 'static';
      $config['seoTitle'] = $config['page']->seo_title;
      $config['seoDesc'] = $config['page']->seo_description;
      $config['seoKey'] = $config['page']->seo_tags;

      $this->load->view('public/common/public-header', $config);
      $this->load->view('public/blog-details');
      $this->load->view('public/common/public-footer');
    } else {
      $this->session->set_flashdata('type', 'error');
      $this->session->set_flashdata('title', 'Error');
      $this->session->set_flashdata('msg', 'No direct script access allowed.');
      return redirect(base_url('blog.php'));
    }
  }
}
?>
